@@ -47,6 +47,10 @@ class MembershipStatusDetailFilter(SimpleListFilter):
         return zip(status_detail_list, status_detail_list)
 
     def queryset(self, request, queryset):
+
+        if not self.value() == 'archive':
+            queryset = queryset.exclude(status_detail='archive')
+
         if self.value():
             return queryset.filter(status_detail=self.value())
         else:
@@ -214,8 +218,6 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
             'industry',
             'company_size',
             'promotion_code',
-            # 'directory',
-            # 'sig_user_group_ids',
         )}
     )
 
@@ -251,6 +253,35 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         status
     )
 
+    search_fields = [
+        'user__first_name',
+        'user__last_name',
+        'user__email',
+        'member_number',
+    ]
+
+    list_display = [
+        'name',
+        'email',
+        'member_number',
+        'membership_type_link',
+        'get_approve_dt',
+        'get_status',
+        'get_invoice',
+    ]
+
+    list_filter = [
+        MembershipStatusDetailFilter,
+        'membership_type',
+    ]
+
+    actions = [
+        approve_selected,
+        renew_selected,
+        disapprove_selected,
+        expire_selected,
+    ]
+
     def get_fieldsets(self, request, instance=None):
         demographics_fields = get_selected_demographic_field_names(
             instance and instance.app)
@@ -318,42 +349,12 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         if dt:
             return dt.strftime('%b %d, %Y, %I:%M %p')
         return u''
-
     get_approve_dt.short_description = u'Approved On'
 
-    def get_actions(self, request):
-        actions = super(MembershipDefaultAdmin, self).get_actions(request)
-        actions['delete_selected'][0].short_description = "Delete Selected"
-        return actions
-
-    search_fields = [
-        'user__first_name',
-        'user__last_name',
-        'user__email',
-        'member_number',
-    ]
-
-    list_display = [
-        'name',
-        'email',
-        'member_number',
-        'membership_type_link',
-        'get_approve_dt',
-        'get_status',
-        'get_invoice',
-    ]
-
-    list_filter = [
-        'membership_type',
-        MembershipStatusDetailFilter,
-    ]
-
-    actions = [
-        approve_selected,
-        renew_selected,
-        disapprove_selected,
-        expire_selected,
-    ]
+    # def get_actions(self, request):
+    #     actions = super(MembershipDefaultAdmin, self).get_actions(request)
+    #     actions['delete_selected'][0].short_description = "Delete Selected"
+    #     return actions
 
     def save_form(self, request, form, change):
         """
@@ -404,10 +405,6 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
 
         return super(MembershipDefaultAdmin, self).response_change(request, obj)
 
-    def queryset(self, request):
-        qs = super(MembershipDefaultAdmin, self).queryset(request)
-        return qs.exclude(status_detail='archive').order_by('-application_approved_dt')
-
     def get_urls(self):
         """
         Add the export view to urls.
@@ -580,7 +577,7 @@ class MembershipTypeAdmin(admin.ModelAdmin):
 
         ('Other Options', {'fields': (
             'expiration_grace_period', ('require_approval',
-            'admin_only'), 'position', 'status_detail')}),
+            'admin_only'), 'require_payment_approval', 'position', 'status_detail')}),
     )
 
     form = MembershipTypeForm
@@ -934,10 +931,10 @@ class AppEntryAdmin(admin.ModelAdmin):
             entry.judge = request.user
             entry.save()
 
-    def get_actions(self, request):
-        actions = super(AppEntryAdmin, self).get_actions(request)
-        del actions['delete_selected']
-        return actions
+    # def get_actions(self, request):
+    #     actions = super(AppEntryAdmin, self).get_actions(request)
+    #     del actions['delete_selected']
+    #     return actions
 
     def entry_name(self):
         return '<a href="%s">%s</a>' % (self.get_absolute_url(), self)
