@@ -232,6 +232,7 @@ class MembershipTypeForm(forms.ModelForm):
                   #'corporate_membership_only',
                   #'corporate_membership_type_id',
                   'require_approval',
+                  'require_payment_approval',
                   'admin_only',
                   'renewal_require_approval',
                   'renewal_period_start',
@@ -763,7 +764,7 @@ class MembershipDefault2Form(forms.ModelForm):
 
     def __init__(self, app_field_objs, *args, **kwargs):
         request_user = kwargs.pop('request_user')
-        customer = kwargs.pop('customer')
+        customer = kwargs.pop('customer', request_user)
         self.membership_app = kwargs.pop('membership_app')
         multiple_membership = kwargs.pop('multiple_membership', False)
 
@@ -895,9 +896,6 @@ class MembershipDefault2Form(forms.ModelForm):
         # adding membership record
         membership.renewal = is_renewal
 
-        # assign member number
-        membership.set_member_number()
-
         # set app
         membership.app = self.membership_app
 
@@ -907,33 +905,32 @@ class MembershipDefault2Form(forms.ModelForm):
         # save many-to-many data for the form
         self.save_m2m()
 
+        # assign member number
+        membership.set_member_number()
+        membership.save()
+
         return membership
 
 
 class MembershipExportForm(forms.Form):
+
     STATUS_DETAIL_CHOICES = (
-            (' ', 'ALL'),
-            ('active', 'Active'),
-            ('pending', 'Pending'),
-            ('expired', 'Expired'),
-                             )
-    EXPORT_TYPE_CHOICES = (
-            ('main_fields', 'Main Fields Only (for faster download)'),
-            ('all_fields', 'ALL Fields')
-                           )
-    export_format = forms.ChoiceField(
-                label=_('Export Format'),
-                choices=(('csv', 'csv (Export)'),))
-    export_status_detail = forms.ChoiceField(
-                label=_('Export Status Detail'),
-                choices=STATUS_DETAIL_CHOICES,
-                initial='active'
-                )
-    export_type = forms.ChoiceField(
-                label=_('Export Type'),
-                choices=EXPORT_TYPE_CHOICES,
-                widget=forms.widgets.RadioSelect
-                )
+        ('active', ' Export Active Memberships'),
+        ('pending', 'Export Pending Memberships'),
+        ('expired', 'Export Expired Memberships'),
+    )
+
+    EXPORT_FIELD_CHOICES = (
+        ('main_fields', 'Export Main Fields (fastest)'),
+        ('all_fields', 'Export All Fields'),
+    )
+
+    EXPORT_TYPE_CHOICES = [(u'all', 'Export All Types')] + list(MembershipType.objects.values_list('pk', 'name'))
+
+    export_format = forms.CharField(widget=forms.HiddenInput(), initial='csv')
+    export_status_detail = forms.ChoiceField(choices=STATUS_DETAIL_CHOICES)
+    export_fields = forms.ChoiceField(choices=EXPORT_FIELD_CHOICES)
+    export_type = forms.ChoiceField(choices=EXPORT_TYPE_CHOICES)
 
 
 class NoticeForm(forms.ModelForm):
