@@ -156,39 +156,35 @@ def get_membership_type_choices(request_user, customer, membership_app, corp_mem
 
     for mt in membership_types:
         renew_mode = False
-        elligable = isinstance(customer, AnonymousUser)
         if isinstance(customer, User):
             m_list = MembershipDefault.objects.filter(user=customer, membership_type=mt)
-            renew_mode = len(m_list)
-            elligable = any([m.can_renew() for m in m_list])
+            renew_mode = any([m.can_renew() for m in m_list])
 
         mt.renewal_price = mt.renewal_price or 0
-
-        if is_superuser or elligable:
-            if renew_mode:
-                price_display = (price_fmt + renew_fmt) % (
+        if renew_mode:
+            price_display = (price_fmt + renew_fmt) % (
+                mt.name,
+                currency_symbol,
+                mt.renewal_price
+            )
+        else:
+            if mt.admin_fee:
+                price_display = (price_fmt + admin_fee_fmt) % (
                     mt.name,
                     currency_symbol,
-                    mt.renewal_price
+                    mt.price,
+                    currency_symbol,
+                    mt.admin_fee
                 )
             else:
-                if mt.admin_fee:
-                    price_display = (price_fmt + admin_fee_fmt) % (
-                        mt.name,
-                        currency_symbol,
-                        mt.price,
-                        currency_symbol,
-                        mt.admin_fee
-                    )
-                else:
-                    price_display = (price_fmt) % (
-                        mt.name,
-                        currency_symbol,
-                        mt.price
-                    )
+                price_display = (price_fmt) % (
+                    mt.name,
+                    currency_symbol,
+                    mt.price
+                )
 
-            price_display = mark_safe(price_display)
-            mt_list.append((mt.id, price_display))
+        price_display = mark_safe(price_display)
+        mt_list.append((mt.id, price_display))
 
     return mt_list
 
@@ -237,19 +233,24 @@ def get_selected_demographic_field_names(membership_app=None):
     return selected_field_names
 
 
-def get_membership_rows(user_field_list,
-                    profile_field_list,
-                    demographic_field_list,
-                    membership_field_list,
-                    invoice_field_list,
-                    foreign_keys,
-                    export_status_detail='',
-                    cp_id=0):
+def get_membership_rows(
+        user_field_list,
+        profile_field_list,
+        demographic_field_list,
+        membership_field_list,
+        invoice_field_list,
+        foreign_keys,
+        export_type=u'all',
+        export_status_detail=u'',
+        cp_id=0):
 
     # grab all except the archived
     memberships = MembershipDefault.objects.filter(
         status=True).exclude(status_detail='archive')
 
+    if not export_type == 'all':
+        memberships = memberships.filter(membership_type=export_type)
+
     if export_status_detail:
         if export_status_detail == 'pending':
             memberships = memberships.filter(
@@ -303,12 +304,13 @@ def get_obj_field_value(field_name, obj, is_foreign_key=False):
 
 
 def process_export(
-        export_type='all_fields',
+        export_fields='all_fields',
+        export_type='all',
         export_status_detail='active',
         identifier=u'', user_id=0, cp_id=0):
     from tendenci.core.perms.models import TendenciBaseModel
 
-    if export_type == 'main_fields':
+    if export_fields == 'main_fields':
 
         base_field_list = []
 
@@ -335,6 +337,7 @@ def process_export(
         demographic_field_list = []
 
         membership_field_list = [
+            'app',
             'membership_type',
             'corp_profile_id',
             'corporate_membership_id',
@@ -393,8 +396,8 @@ def process_export(
         demographic_field_list)
 
     # list of foreignkey fields
-    if export_type == 'main_fields':
-        fks = ['membership_type']
+    if export_fields == 'main_fields':
+        fks = ['membership_type', 'app']
     else:
 
         user_fks = [
@@ -416,8 +419,9 @@ def process_export(
         fks = Set(user_fks + profile_fks + demographic_fks + membership_fks)
 
     membership_ids_dict = dict(MembershipType.objects.all().values_list('id', 'name'))
+    app_ids_dict = dict(MembershipApp.objects.all().values_list('id', 'name'))
 
-    identifier = identifier or int(time.time())
+    identifier = identifier or int(ttime.time())
     file_name_temp = 'export/memberships/%s_%d_temp.csv' % (identifier, cp_id)
 
     with default_storage.open(file_name_temp, 'wb') as csvfile:
@@ -431,6 +435,7 @@ def process_export(
             membership_field_list,
             invoice_field_list,
             fks,
+            export_type,
             export_status_detail,
             cp_id)
 
@@ -453,6 +458,9 @@ def process_export(
                     elif field_name == 'membership_type':
                         # display membership type name instead of id
                         item = membership_ids_dict[item]
+                    elif field_name == 'app':
+                        # display membership type name instead of id
+                        item = app_ids_dict[item]
                 item = smart_str(item).decode('utf-8')
                 items_list.append(item)
             csv_writer.writerow(items_list)
@@ -483,7 +491,7 @@ def process_export(
             'site_url': site_url,
             'site_display_name': site_display_name,
             'export_status_detail': export_status_detail,
-            'export_type': export_type,
+            'export_fields': export_fields,
             'corp_profile': corp_profile}
 
         subject = render_to_string(
@@ -1525,6 +1533,13 @@ class ImportMembDefault(object):
             if memb.status and memb.status_detail == 'active':
                 memb.join_dt = datetime.now()
 
+        # no application_approved_dt - set one
+        if not hasattr(memb, 'application_approved_dt') or not memb.application_approved_dt:
+            if memb.status and memb.status_detail == 'active':
+                memb.application_approved = True
+                memb.application_approved_dt = memb.join_dt
+                memb.application_approved_denied_dt = memb.join_dt
+
         # no expire_dt - get it via membership_type
         if not hasattr(memb, 'expire_dt') or not memb.expire_dt:
             if memb.membership_type:
